/*
 * Copyright (c) 2010 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * The <code>AbilityCommand</code> represents a command in a GF input file that
 * adds an ability to the previously defined GF.
 */
public class AbilityCommand extends CommandValued
{
    /**
     * Creates a new <code>AbilityCommand</code> to be added to a parser.
     */
    public AbilityCommand()
    {
	super("ability", 1);
    }

    /**
     * Executes the ability command on the given simulation.
     *
     * @param value the total AP cost of the ability.
     * @param argument the name of the ability.
     * @param simulation the simulation on which to execute the command.
     * @throws ParserException if there has been no GF defined yet, or if the
     * ability name is a duplicate.
     */
    protected void execute(int value, String argument, Simulation simulation)
	throws ParserException
    {
	int gfs = simulation.numGFs();
	if (gfs == 0)
	    throw new ParserException("No GF defined for ability " + argument);
	GuardianForce gf = simulation.getGF(gfs-1);
	try {
	    gf.append(new Ability(argument, value));
	}
	catch (IllegalArgumentException iae) {
	    throw new ParserException("Duplicate ability for " + gf.getName() +
				      ": " + argument);
	}
    }
}