/*
 * Copyright (c) 2010 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * The <code>CommandPlain</code> class represents a command that consists only
 * of a single identifying word with no following arguments.
 */
public abstract class CommandPlain extends Command
{
    /**
     * Creates a new <code>CommandPlain</code> with the given identifying word.
     *
     * @param word the identifying word.
     */
    public CommandPlain(String word)
    {
	super(word);
    }

    /**
     * Parses the remainder of the input line after the single identifying
     * word.
     *
     * @param rest the remainder of the line.
     * @param simulation the simulation on which to execute the parsed command.
     * @throws ParserException if the remainder of the line is not empty.
     */
    protected void parseRest(String rest, Simulation simulation)
	throws ParserException
    {
	if (rest.isEmpty() == false)
	    throw new ParserException("Unexpected argument for " + this.word);
	this.execute(simulation);
    }

    /**
     * Executes the user command on the given simulation.
     *
     * @param simulation the simulation on which to execute the command.
     * @throws ParserException if the command is illegal.
     */
    protected abstract void execute(Simulation simulation)
	throws ParserException;
}