/*
 * Copyright (c) 2010 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * The <code>GFCommand</code> represents a command in a GF input file that
 * specifies a new Guardian Force.
 */
public class GFCommand extends CommandString
{
    /**
     * Creates a new <code>GFCommand</code> to be added to a parser.
     */
    public GFCommand()
    {
	super("gf");
    }

    /**
     * Executes the GF command on the given simulation.
     *
     * @param argument the name of the GF.
     * @param simulation the simulation on which to execute the command.
     * @throws ParserException if the GF name is a duplicate.
     */
    protected void execute(String argument, Simulation simulation)
	throws ParserException
    {
	try {
	    simulation.add(new GuardianForce(argument));
	}
	catch (IllegalArgumentException iae) {
	    throw new ParserException("Duplicate GF name: " + argument);
	}
    }
}