/*
 * Copyright (c) 2010 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * The <code>GetCommand</code> represents a command in a battle input file that
 * specifies when a GF is received.
 */
public class GetCommand extends CommandString
{
    /**
     * Creates a new <code>GetCommand</code> to be added to a parser.
     */
    public GetCommand()
    {
	super("get");
    }

    /**
     * Executes the get command on the given simulation.
     *
     * @param argument the name of the GF.
     * @param simulation the simulation on which to execute the command.
     * @throws ParserException if the GF does not exist in the simulation or
     * if it has already been received.
     */
    protected void execute(String argument, Simulation simulation)
	throws ParserException
    {
	GuardianForce gf = simulation.getGF(argument);
	if (gf == null)
	    throw new ParserException("Invalid GF name: " + argument);
	else if (gf.isAcquired())
	    throw new ParserException("GF acquired more than once: " +
				      argument);

	int afterBattles = simulation.numBattles();
	gf.setAcquiredAfter(afterBattles);
    }
}