/*
 * Copyright (c) 2010 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * The <code>NoMenuCommand</code> represents a command in a battle input file
 * that specifies that you were not able to open the menu prior to the last
 * defined battle..
 */
public class NoMenuCommand extends CommandPlain
{
    /**
     * Creates a new <code>NoMenuCommand</code> to be added to a parser.
     */
    public NoMenuCommand()
    {
	super("withoutmenu");
    }

    /**
     * Executes the no menu command on the given simulation.
     *
     * @param simulation the simulation on which to execute the command.
     * @throws ParserException if there are no battles in the simulation or if
     * the no menu command is a dupliate.
     */
    protected void execute(Simulation simulation) throws ParserException
    {
	int index = simulation.numBattles() - 1;
	if (index < 0)
	    throw new ParserException("No battle for which to prevent " +
				      "menu access");
	Battle battle = simulation.getBattle(index);
	if (battle.canMenuBefore() == false)
	    throw new ParserException("Duplicate prevention of menu access");
	battle.setMenuBefore(false);
    }
}